==> activity-center-api-0.16.51-20231225.061258-4-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/pc/JmPackageDTO.java <==
package cn.com.duiba.tuia.activity.center.api.dto.pc;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class JmPackageDTO implements Serializable {
    private Long id;

    private String name;

    private String desc;

    private Short fileVersion;

    private Integer operatorId;

    private String operatorName;

    private Integer modifyId;

    private String modifyName;

    private String changeLog;

    private Boolean enableStatus;

    private Date gmtCreate;

    private Date gmtModified;

    private String schema;

    private List<JmPackageVersionDTO> versionEntityList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name == null ? null : name.trim();
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc == null ? null : desc.trim();
    }

    public Short getFileVersion() {
        return fileVersion;
    }

    public void setFileVersion(Short fileVersion) {
        this.fileVersion = fileVersion;
    }

    public Integer getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Integer operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName == null ? null : operatorName.trim();
    }

    public Integer getModifyId() {
        return modifyId;
    }

    public void setModifyId(Integer modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName == null ? null : modifyName.trim();
    }

    public Boolean getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Boolean enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getSchema() {
        return schema;
    }

    public void setSchema(String schema) {
        this.schema = schema == null ? null : schema.trim();
    }

    public String getChangeLog() {
        return changeLog;
    }

    public void setChangeLog(String changeLog) {
        this.changeLog = changeLog;
    }

    public List<JmPackageVersionDTO> getVersionEntityList() {
        return versionEntityList;
    }

    public void setVersionEntityList(List<JmPackageVersionDTO> versionEntityList) {
        this.versionEntityList = versionEntityList;
    }
}

==> activity-center-api-0.16.59-20240325.020301-2-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/pc/JmPackageDTO.java <==
package cn.com.duiba.tuia.activity.center.api.dto.pc;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class JmPackageDTO implements Serializable {
    private Long id;

    private String name;

    private String desc;

    private Integer fileVersion;

    private Integer operatorId;

    private String operatorName;

    private Integer modifyId;

    private String modifyName;

    private String changeLog;

    private Integer enableStatus;

    private Date gmtCreate;

    private Date gmtModified;

    private String schema;

    private List<JmPackageVersionDTO> versionEntityList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name == null ? null : name.trim();
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc == null ? null : desc.trim();
    }

    public Integer getFileVersion() {
        return fileVersion;
    }

    public void setFileVersion(Integer fileVersion) {
        this.fileVersion = fileVersion;
    }

    public Integer getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Integer operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName == null ? null : operatorName.trim();
    }

    public Integer getModifyId() {
        return modifyId;
    }

    public void setModifyId(Integer modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName == null ? null : modifyName.trim();
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getSchema() {
        return schema;
    }

    public void setSchema(String schema) {
        this.schema = schema == null ? null : schema.trim();
    }

    public String getChangeLog() {
        return changeLog;
    }

    public void setChangeLog(String changeLog) {
        this.changeLog = changeLog;
    }

    public List<JmPackageVersionDTO> getVersionEntityList() {
        return versionEntityList;
    }

    public void setVersionEntityList(List<JmPackageVersionDTO> versionEntityList) {
        this.versionEntityList = versionEntityList;
    }
}
